Simple tests
------------

Ensure your device works with these simple tests.

.. literalinclude:: ../examples/lsm303agr_mag_simpletest.py
    :caption: examples/lsm303agr_mag_simpletest.py
    :linenos:

.. literalinclude:: ../examples/lsm303agr_mag_interrupt.py
    :caption: examples/lsm303agr_mag_interrupt.py
    :linenos:

examples/lsm303agr_mag_interrupt.py